var group__new__in__4__1 =
[
    [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html", [
      [ "Type", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7", [
        [ "kUnknown", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7a8e792321b79a4aa90e75bd3fcc2e4141", null ],
        [ "kInteger", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7aa1acc5720dd4e85ceea5578a6cf14ae6", null ],
        [ "kFloat", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7a5686197bafb177bdc82550848416a1ad", null ],
        [ "kObject", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7ad74f4c7c6562dc3f8339a8bba2d28dd0", null ],
        [ "kRect", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7acdab9612499542c402c5594723c24bf7", null ],
        [ "kPoint", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7a38146a834eece30f0cbb59d1f0e05145", null ],
        [ "kColor", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7afc0133ebaa6c307b2388ecf5f72f6fdf", null ],
        [ "kTransformMatrix", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a1d1cfd8ffb84e947f82999c682b666a7af3632aaa54bb132cf1025b100bb86f83", null ]
      ] ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#aa0af03308c33054ca74270100537c554", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a66e8126d2c20b958c90758d1d86e7d25", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a8b841313c688555b94d1a3d895d4dd8a", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#ae6bc183d8118775168153d5b691b21c7", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#aa791debe9240ccdb97266e08158e51c5", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a509bc8aebf76d527b986f35279bba348", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a36163889002d339e5f550e01e7ba9491", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a3d2cfe9b97b19dc90b4c640aab8abf9a", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a9800b1a118fde6c35fca48949c5af20c", null ],
      [ "Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#aff37ac13c13c2cb65ad09a0af4044dc1", null ],
      [ "~Property", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#ae53c35255368e13c84b9592b1ac9fdc3", null ],
      [ "getColor", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#aa1c9eb1b8b13dca8e9caa7376fcd926e", null ],
      [ "getFloat", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#af4c9462d5f17112ed3538017f60a623e", null ],
      [ "getInteger", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a7994a681702338f35f257bf3142bcf45", null ],
      [ "getObject", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a6a695b35d7f58548e25e768b141d77a9", null ],
      [ "getPoint", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#aa497e2df11f92067d8f6fb36d5aa936b", null ],
      [ "getRect", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#ab48980438144d9f68d03622e4881b784", null ],
      [ "getTransform", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#afd973675a1459432ab10c56cd192cc6d", null ],
      [ "getType", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#a97c56d51eec84be3e856eb0ca6ebd3d4", null ],
      [ "operator=", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#aff9ca6cde42088f8763cb9b5538eda36", null ],
      [ "operator=", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_property.html#aba90db21fe594a75f15e02db80f37a59", null ]
    ] ],
    [ "IFilter", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html", [
      [ "CreateFunction", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#ade6c96a2417ad64e25f2cbabb8186c7a", null ],
      [ "getDescription", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#a0e2759fd10c935b91163d934d281fc79", null ],
      [ "getNumProperties", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#acc078bcc942c8682c254cbd63a19a932", null ],
      [ "getProperty", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#a98bbd2a4cd6e0432b3fdd7aea6aa7053", null ],
      [ "getPropertyName", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#a5c5135480eddaaa90cea41845184b00c", null ],
      [ "getPropertyType", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#ac6509d541cd318521e0e64488f1e4bdf", null ],
      [ "getPropertyType", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#a290b0a2609be8e27291c6aac62b2ab1e", null ],
      [ "run", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#a1b716b0a6c671a625cbb337196019d93", null ],
      [ "setProperty", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#a19bed293fcb5410ec188c0275c0a3781", null ],
      [ "setProperty", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_i_filter.html#a387ff07b047040c10565449f98fc45c0", null ]
    ] ],
    [ "Factory", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html", [
      [ "FilterMap", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#a6d34792644e5765a80de948cefa0d271", null ],
      [ "createFilter", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#acbb22ea5ba0578ac2e29f75fcf523d64", null ],
      [ "getFilterName", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#a611fc0bbfd8c91d6720854e0416fefa9", null ],
      [ "getInstance", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#a87eac43242249d8b4763e0ae4e11c748", null ],
      [ "getNumFilters", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#ad2138bf4b0a0573bb0c896997a1d1040", null ],
      [ "registerFilter", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#a4806e2a49b578963cf51c5e1572fe07c", null ],
      [ "unregisterFilter", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#a86201fe297c2a0f412bda516d5e14bef", null ],
      [ "filters", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_factory.html#a439b7210ef1bdec4bb9fa680d9dbfd94", null ]
    ] ],
    [ "FilterBase", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html", [
      [ "FilterBase", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a46a4be1b5b7164ce2404e7aff4629dda", null ],
      [ "getDescription", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a2ff96652e89b99f424c047a59e85850d", null ],
      [ "getInputBitmap", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#ad3700cbafe18faf1bbecec9c154e6f77", null ],
      [ "getNumProperties", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a6a5502d43a67e40110404458c8ec4a3e", null ],
      [ "getProperty", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a73bde71e57a2899c40a000c14d69c699", null ],
      [ "getPropertyName", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a9b6dcb14e9403544e24ee52fbb06fa37", null ],
      [ "getPropertyType", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#af9ef2789258c8c84e5168924b718c981", null ],
      [ "getPropertyType", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a84c34c7318ccd2b69db1226ab3b4e22f", null ],
      [ "registerProperty", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#ac259fc1c6e9d709236e65be6b1fd52ae", null ],
      [ "setProperty", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#af638154f83f2dc59b42a3e676e162a8b", null ],
      [ "setProperty", "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a639c56d7d108e8a0f5706d11137a7cd2", null ]
    ] ],
    [ "CCommandMenuItem", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html", [
      [ "Desc", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html", [
        [ "Desc", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a336bc5b492c98cc1d51dd2b049dbcd5f", null ],
        [ "~Desc", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#af91a3895109d5caaaf2ccfe47ccc646d", null ],
        [ "Desc", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a207f9d3548177b0fe8dc16d1e4b07857", null ],
        [ "Desc", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#ae601b757bc0b6be1b2758808b4521f78", null ],
        [ "Desc", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a3c3d4763bdf49b525378747a358ad495", null ],
        [ "commandCategory", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a8d05d7a89a24ba56b920aa4d4afd16e8", null ],
        [ "commandName", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a655bbc658989f60759522b1f841ac046", null ],
        [ "flags", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#ae51934333edd3a61c06a695837f30595", null ],
        [ "icon", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a0150fcd1c8ca13b3acca8f7b65a91187", null ],
        [ "keycode", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#ad14b5c65c00b0a1df79e0ef23e484611", null ],
        [ "keyModifiers", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a1ba8e665dce0790fcf07cc86a47a161d", null ],
        [ "tag", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a34c721addea3f88cf25164c911c60cec", null ],
        [ "target", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#aed900c4739e85fcf415af90617f7aa4f", null ],
        [ "title", "struct_v_s_t_g_u_i_1_1_c_command_menu_item_1_1_desc.html#a079f062c4955dddcbe528b0b9e00d6e5", null ]
      ] ],
      [ "SelectedCallbackFunction", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a7f7dc0c74b53825eff656aeb16030e43", null ],
      [ "ValidateCallbackFunction", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a027fb38ab6a8909a2317dcc0666a24ce", null ],
      [ "CCommandMenuItem", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a71bdfb5ee5cb32fe24551ab9a2f6116d", null ],
      [ "CCommandMenuItem", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#abc6e042fd84ef1c71765d1f4962b2c4a", null ],
      [ "CCommandMenuItem", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a112ab9c6df2a72fa16b1726d8f44dcab", null ],
      [ "~CCommandMenuItem", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a633d1fbc200910e4fa6a1771c53bdc9e", null ],
      [ "execute", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a61af3e60b94ae3e748f6fbac1e794af7", null ],
      [ "getCommandCategory", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#aa0fbe99b5c9c7f9571c4b848cdde866f", null ],
      [ "getCommandName", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a2bad0d989fd5cc47e2156c9bae615a8a", null ],
      [ "getItemTarget", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a48e681ae5b14c1df8bb366d468f12c1a", null ],
      [ "isCommandCategory", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a23e814c0c96ec71b1d0ddc9d8bc1d9e0", null ],
      [ "isCommandName", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#afe6727257feec406a19d458a7411c758", null ],
      [ "setActions", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#ac1322cfc12d498e36cdb4b17860d4b1c", null ],
      [ "setCommandCategory", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#ac779edb42d25525a6ca144149be785ec", null ],
      [ "setCommandName", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#aeea46e2d2fdfdbb60679a8a484f91516", null ],
      [ "setItemTarget", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#ae3ebb496ba45a966780bda46e446a523", null ],
      [ "validate", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a41d45236c37b75848f4b1667a11fb50e", null ],
      [ "commandCategory", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a8d05d7a89a24ba56b920aa4d4afd16e8", null ],
      [ "commandName", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a655bbc658989f60759522b1f841ac046", null ],
      [ "itemTarget", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a520ba53cab2597c4f61227ec9a8fc761", null ],
      [ "selectedFunc", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#a3f1175417e0b0f4fcb0b7cf7ded54962", null ],
      [ "validateFunc", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html#aef8b81d61d056028f0cc265e02abc1ee", null ]
    ] ],
    [ "COpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html", [
      [ "COpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a8161e211721e4e71d5acb033c5340c7b", null ],
      [ "~COpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a0fe18355ace65552f3a5f73085a22151", null ],
      [ "attached", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
      [ "drawOpenGL", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#ac5d2cf8c6dc7b4082214b5e2b9e8c135", null ],
      [ "getPixelFormat", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a4a03e8d72ab5943532c53fd9d49845a3", null ],
      [ "getPlatformOpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a101bc8d97f2f5e71628f17f489abd962", null ],
      [ "invalidRect", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a5803a16bd396a0d032c08c29a60e4f78", null ],
      [ "newCopy", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a5b303fef30c4644882aaa04f5ad669ca", null ],
      [ "onScaleFactorChanged", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#abcff5876c86f2ad4e32a090db7db147a", null ],
      [ "parentSizeChanged", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#afc5cbc672fb3b31e9a63b3f1d34f4c65", null ],
      [ "platformOpenGLViewCreated", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a1d123b17ceb583261afb3971ebe8815c", null ],
      [ "platformOpenGLViewSizeChanged", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a366824fabc6b6fd5c5d5662533a5ede8", null ],
      [ "platformOpenGLViewWillDestroy", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a46f01e34c6ac971e936af3c6406637c7", null ],
      [ "removed", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a157ad241be4354121739aac80cf3cd3d", null ],
      [ "reshape", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#a722bdd040055d25171e3a8e90368bd9d", null ],
      [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#afa3d86320cb051cecb3c687a523ba787", null ],
      [ "setVisible", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html#aa57c516e3f55ae402284f15c61739956", null ]
    ] ],
    [ "CRowColumnView", "class_v_s_t_g_u_i_1_1_c_row_column_view.html", [
      [ "LayoutStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21d", [
        [ "kLeftTopEqualy", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da3f923be75f1bf9141348ca5418fc6bac", null ],
        [ "kCenterEqualy", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21dad7ec32cb3ed9b1ce69a8bdeaca552e4f", null ],
        [ "kRightBottomEqualy", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da20f3404c4512020afb660b52b249ce31", null ],
        [ "kStretchEqualy", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da9ebb074156462ac646d26659bc1dfe1f", null ],
        [ "kTopLeft", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da193111a954dec0c3efae0cc83eb09d48", null ],
        [ "kTopCenter", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da2cef2cc215f2e6411e155c5540b62eb0", null ],
        [ "kTopRight", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da9e626b914e7ed24404f72bffdfb80833", null ],
        [ "kMiddleLeft", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da18202a28a023b7be91dbe03a648f6f1d", null ],
        [ "kMiddleCenter", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21dae5b3d56175f3fff6b7ae8177e9c551d9", null ],
        [ "kMiddleRight", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da536a65649970029eeac49c7fb0738fec", null ],
        [ "kBottomLeft", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21daa8529e3d216c6ce5f204241afa9e4234", null ],
        [ "kBottomCenter", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da5e66fbe343a9b934dae776687f64e8a6", null ],
        [ "kBottomRight", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a68fa32a8672954b46956a5acfb81d21da4fb10e55ef539fc3fbd68e30cd3f99bc", null ]
      ] ],
      [ "Style", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#addb2fa415e015ee482fa2cd9eba96af7", [
        [ "kRowStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#addb2fa415e015ee482fa2cd9eba96af7a8708c8e639c25dc586d6b9ceb9d5a50d", null ],
        [ "kColumnStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#addb2fa415e015ee482fa2cd9eba96af7a2306b07529be356f761e9213fe60c39b", null ]
      ] ],
      [ "CRowColumnView", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#acf0aed668eb2e673899b51b113f6c6bf", null ],
      [ "getLayoutStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a6d3d6da45d5568b05210318ece766fd7", null ],
      [ "getMargin", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#af0f853f16d64dd2742f036977436ba53", null ],
      [ "getMaxChildViewSize", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a82ab61c920653e54d5721c2915810353", null ],
      [ "getSpacing", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a79e158dc3a4eba2b6af28fe6fcf1a83f", null ],
      [ "getStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ac787788a28e6eb99ff6217c6ff56be5d", null ],
      [ "getViewResizeAnimationTime", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ab965d2760605082ee783176f72815248", null ],
      [ "hideClippedSubviews", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ab18e6f91a9f17e2a12386b29232a542f", null ],
      [ "isAnimateViewResizing", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#aeb24c70b1bf57c6a770c66120aff694c", null ],
      [ "layoutViews", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a0dda45a3c60202a25a9166907ffff0fe", null ],
      [ "layoutViewsEqualSize", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ae7c563dcda3ecdb30511be705b188314", null ],
      [ "newCopy", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a5b303fef30c4644882aaa04f5ad669ca", null ],
      [ "notify", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a4b7d3ab731844a367db3a0d77af8e9ac", null ],
      [ "resizeSubView", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a0fefdf6fe81e54814252ae986cc66bd3", null ],
      [ "setAnimateViewResizing", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ae85758bbcf6e67deb447100dde4357b5", null ],
      [ "setHideClippedSubviews", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a49a22b972c05c773110b42f52aef72d9", null ],
      [ "setLayoutStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a2c0f4707eb103811cdebaaf3fe25a323", null ],
      [ "setMargin", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a468a649668393d93bca4830d74c14b44", null ],
      [ "setSpacing", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a04736dc8adf5632e628ea88644498a5e", null ],
      [ "setStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a711c104609272c5630d992a2aa12b653", null ],
      [ "setViewResizeAnimationTime", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a78a8a70befe29de41c329a5596a592df", null ],
      [ "sizeToFit", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a64c95c189130160521d50820d9982242", null ],
      [ "flags", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ae51934333edd3a61c06a695837f30595", null ],
      [ "layoutGuard", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a76d87a5d26a7ab23ee058c5f62bd4ed5", null ],
      [ "layoutStyle", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a7220665d3182582c64f78b2e920ec6cf", null ],
      [ "margin", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ac75fc835ed41509adc9eee92b2ae3fe5", null ],
      [ "spacing", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a3e972ac45d440d7fa0c279f69b4a4f43", null ],
      [ "style", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a4b798253dd80ae013643a26e88e2bf6a", null ],
      [ "viewResizeAnimationTime", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a2cdfd0f81c97aaded87f0754b9ec162d", null ]
    ] ],
    [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html", [
      [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#af20982221f241e08beb9f136edf7cafe", null ],
      [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#ac41f4f79f271e431b286b7e3b63b34cf", null ],
      [ "~CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a1d632ae69018ae277288375db0d60325", null ],
      [ "attached", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
      [ "beforeDelete", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#adc36f3faf62b04701b310c82c0b605a5", null ],
      [ "drawBackgroundRect", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a712bcd14cfc09e409577317765f7b9e7", null ],
      [ "drawRect", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#ac3627a2e2abcfe4e6df2a77e4829446a", null ],
      [ "getShadowBlurSize", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#ac37481dfedaba7bdbf3929c892cc8083", null ],
      [ "getShadowIntensity", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#ac9dd3b4217672f764d773f3d7471e7fd", null ],
      [ "getShadowOffset", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a02b6cfd6e88c77cf6d5c5aa4c8ab7666", null ],
      [ "invalidateShadow", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a34b47c35a9d741b872eec12db613d23d", null ],
      [ "newCopy", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a5b303fef30c4644882aaa04f5ad669ca", null ],
      [ "notify", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a4b7d3ab731844a367db3a0d77af8e9ac", null ],
      [ "onScaleFactorChanged", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#abcff5876c86f2ad4e32a090db7db147a", null ],
      [ "removed", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a157ad241be4354121739aac80cf3cd3d", null ],
      [ "setShadowBlurSize", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#aa36fe50e5c42df6629747fdac2b7cb2a", null ],
      [ "setShadowIntensity", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#aa8a97004516bb7d62621615837648970", null ],
      [ "setShadowOffset", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#aa7ca051d2d14510fa65ace37971805b7", null ],
      [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#afa3d86320cb051cecb3c687a523ba787", null ],
      [ "viewContainerViewAdded", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a5ccd9882d2063f5d91d14c43359c5ed8", null ],
      [ "viewContainerViewRemoved", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a7fcb29a7fa40ce09b84298dd71d000bd", null ],
      [ "viewContainerViewZOrderChanged", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a0efb0cc9168b353cc3488fbf0784350c", null ],
      [ "dontDrawBackground", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#ac87c9ce1cf97c4a1eea8d82b1b21b6c6", null ],
      [ "scaleFactorUsed", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#aac502449e59f4acff35a45cfca14c807", null ],
      [ "shadowBlurSize", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#a9ec00d0b70e8c9fdcee6e49bda9357c6", null ],
      [ "shadowIntensity", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#ad27188b4d58b321657f2b6cd604e3ba4", null ],
      [ "shadowOffset", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#abc0ba0a500e08b8d5100ba2da2171dbe", null ]
    ] ]
];